jw.mailfilter
=============

This is a daemon filtering and acting on mail in IMAP accounts.

Main features
-------------

- Filtering:
    - on content in mail header
    - on content in mail body
    - on spam status from RBL services
    - on `Pyzor <http://pyzor.org>`_ spam status
    - SURBL spam status
- Actions:
    - delete mail
    - move mail to folder
    - copy mail to folder
    - forward mail
    - report mail to pyzor.org
    - report server's IP to `badips.com <https://badips.com>`_

Installing and running jw.mailfilter
------------------------------------

See the documentation on `Read The Docs <http://jwmailfilter.readthedocs.org>`_.
